@@ -33,19 +33,16 @@ describe 'openstacklib::service_validation' do
       end
 
       it { is_expected.to contain_exec("execute #{title} validation").with(
-        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider  => 'shell',
-        :command   => 'nova list',
-        :timeout   => '60',
-        :tries     => '10',
-        :try_sleep => '2',
-        :logoutput => 'on_failure',
+        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
+        :provider    => 'shell',
+        :command     => 'nova list',
+        :environment => [],
+        :refreshonly => false,
+        :timeout     => '60',
+        :tries       => '10',
+        :try_sleep   => '2',
+        :logoutput   => 'on_failure',
       )}
-
-      it { is_expected.to contain_anchor("create #{title} anchor").with(
-        :require => "Exec[execute #{title} validation]",
-      )}
-
     end
 
     context 'with unless parameter' do
@@ -54,64 +51,64 @@ describe 'openstacklib::service_validation' do
       end
 
       it { is_expected.to contain_exec("execute #{title} validation").with(
-        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider  => 'shell',
-        :command   => 'nova list',
-        :timeout   => '60',
-        :tries     => '10',
-        :try_sleep => '2',
-        :unless    => 'pwd',
+        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
+        :provider    => 'shell',
+        :command     => 'nova list',
+        :refreshonly => false,
+        :timeout     => '60',
+        :tries       => '10',
+        :try_sleep   => '2',
+        :unless      => 'pwd',
       )}
-
-      it { is_expected.to contain_anchor("create #{title} anchor").with(
-        :require => "Exec[execute #{title} validation]",
-      )}
-
     end
 
     context 'with onlyif parameter' do
       let :params do
-        required_params.merge!({:onlyif  => 'pwd' })
+        required_params.merge!({ :onlyif  => 'pwd' })
       end
 
       it { is_expected.to contain_exec("execute #{title} validation").with(
-        :path      => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider  => 'shell',
-        :command   => 'nova list',
-        :timeout   => '60',
-        :tries     => '10',
-        :try_sleep => '2',
-        :onlyif    => 'pwd',
+        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
+        :provider    => 'shell',
+        :command     => 'nova list',
+        :refreshonly => false,
+        :timeout     => '60',
+        :tries       => '10',
+        :try_sleep   => '2',
+        :onlyif      => 'pwd',
       )}
+    end
 
-      it { is_expected.to contain_anchor("create #{title} anchor").with(
-        :require => "Exec[execute #{title} validation]",
+    context 'with environment parameter' do
+      let :params do
+        required_params.merge!({ :environment => ['OS_PASSWORD=secret'] })
+      end
+
+      it { is_expected.to contain_exec("execute #{title} validation").with(
+        :environment => ['OS_PASSWORD=secret'],
       )}
-
     end
 
     context 'when omitting a required parameter command' do
       let :params do
         required_params.delete(:command)
       end
+
       it { expect { is_expected.to raise_error(Puppet::Error) } }
     end
 
   end
 
-  context 'on a Debian osfamily' do
-    let :facts do
-      { :osfamily => "Debian" }
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    include_examples 'openstacklib::service_validation examples'
+      it_configures 'openstacklib::service_validation examples'
+    end
   end
 
-  context 'on a RedHat osfamily' do
-    let :facts do
-      { :osfamily => 'RedHat' }
-    end
-
-    include_examples 'openstacklib::service_validation examples'
-  end
 end
